@@ -1,4 +1,12 @@
 package App::PerlNitpick::Rule::RemoveUnusedVariables;
+# ABSTRACT: Remove unused variables
+
+=encoding UTF-8
+
+This nitpicking rules removes variabse that is declared but not used.
+
+=cut
+
 use Moose;
 use PPI::Document;
 use Perl::Critic::Document;
@@ -23,21 +31,12 @@ sub rewrite {
         if ($el->variables == 1) {
             $el->remove;
         } else {
-            # TODO: figure out which variables in this multi-variable statement are unused.
+            # TODO
         }
+
     }
 
     return $doc;
 }
 
 1;
-
-__END__
-
-=encoding UTF-8
-
-=head1 ABSTRACT
-
-All variables written in the code must be used.
-
-=cut
